package cz.moneta.test.regression.commercial.auto.smartauto;

import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.regression.commercial.auto.smartauto.mockdata.CarMock;
import org.junit.jupiter.api.Disabled;

@Disabled
@TestScenario(name = "Successful filled new calculation for car.")
public class CalculationCarTest extends AbstractTest {
    @JiraTestCase(id = "LAMD-T981")
    @TestCase(name = "Commodity: car, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar1() {
        sharedTasks(CarMock.prepareCalculationCar1());
    }

    @JiraTestCase(id = "LAMD-T982")
    @TestCase(name = "Commodity: car, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: yes, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar1_1() {
        sharedTasks(CarMock.prepareCalculationCar1_1());
    }

    @JiraTestCase(id = "LAMD-T983")
    @TestCase(name = "Commodity: car, Customer: consumer, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar2() {
        sharedTasks(CarMock.prepareCalculationCar2());
    }

    @JiraTestCase(id = "LAMD-T984")
    @TestCase(name = "Commodity: car, Customer: consumer, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar4() {
        sharedTasks(CarMock.prepareCalculationCar4());
    }

    @JiraTestCase(id = "LAMD-T985")
    @TestCase(name = "Commodity: car, Customer: consumer, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar5() {
        sharedTasks(CarMock.prepareCalculationCar5());
    }

    @JiraTestCase(id = "LAMD-T986")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar7() {
        sharedTasks(CarMock.prepareCalculationCar7());
    }

    @JiraTestCase(id = "LAMD-T987")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar8() {
        sharedTasks(CarMock.prepareCalculationCar8());
    }

    @JiraTestCase(id = "LAMD-T988")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: new, Type: M1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar9() {
        sharedTasks(CarMock.prepareCalculationCar9());
    }

    @JiraTestCase(id = "LAMD-T989")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Standard, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar10() {
        sharedTasks(CarMock.prepareCalculationCar10());
    }

    @JiraTestCase(id = "LAMD-T990")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: C2C, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar11() {
        sharedTasks(CarMock.prepareCalculationCar11());
    }

    @JiraTestCase(id = "LAMD-T991")
    @TestCase(name = "Commodity: car, Customer: businessman without vat, State: used, Type: M1, Product: autoCREDIT," +
            "Product Type: Back loan, VAT: no, Insurance: yes, Accident insurance: yes.")
    public void tcCalculationCar12() {
        sharedTasks(CarMock.prepareCalculationCar12());
    }
}